@@ -22,6 +22,16 @@ class Task():
     nodeId = 0
 
     def __init__(self,key:str,priority:int,data:dict):
+        """[初始化Task]
+
+        Args:
+            key (str): [任务关键字，应保持唯一]
+            priority (int): [优先级， 0 < priority < 1000000]
+            data (dict): [数据收集，dict即可，但要保证可json序列化]
+
+        Raises:
+            TaskInitError: [初始化错误，检查数据格式与范围]
+        """
         if isinstance(key, str) and isinstance(priority, int) and isinstance(data, dict) and 0 < priority < 1000000:
             self.key = key
             self.priority = priority if priority < 1000000 else 1000000
@@ -53,12 +63,25 @@ class TaskHub():
         self.back_end_url = back_end_url
 
         pass
+    
     def add(self,task:Task):
+        """[summary]
+
+        Args:
+            task (Task): [要添加的task]
+
+        Raises:
+            TaskAlreadyExist: [task key已经存在]
+
+        Returns:
+            [bool]: [成功返回True]
+        """
+        
         # 加锁
         self.get_lock()
         # 检查是否存在
         if not self.tasks.get( task.key):
-            # 不存在则设置
+            # 不存在则添加
             self.tasks[task.key] =task
             makelog("task added!",4)
             # 释放锁并返回
@@ -73,7 +96,7 @@ class TaskHub():
         # 加锁
         self.get_lock()
         # 根据优先级排序 然后便利
-        for key, task in sorted(self.tasks.items(),reverse=True,key=lambda item:item[1].priority):
+        for key, task in sorted(self.tasks.items(),key=lambda item:item[1].priority):
             # 获取第一个是wait的 设置数据并返回
             if task.status == "wait":
                 task.node_id = nodeId
@@ -85,26 +108,40 @@ class TaskHub():
             self.release_lock()
     
     def upload(self,task:Task):
-                # 加锁
-                self.get_lock()
-                # 检查任务是否存在
-                target_task = self.tasks.get(task.key)
-                if target_task:
-                    # 检查任务状态是否正确
-                    if target_task.status == "running":
-                        # 检查nodeid是否正确
-                        if target_task.nodeId == task.nodeId:
-                            target_task.data = task.data
-                            target_task.status = "done"
-                            self.release_lock()
-                            return True
-                        else:
-                            self.release_lock()
-                            raise NodeIdNotMatch()
+        """[worker 向taskhub 上载数据，标志着该任务的完成]
+
+        Args:
+            task (Task): [任务对象，数据应在task.data]
+
+        Raises:
+            NodeIdNotMatch: [节点id不匹配，该任务不是由该节点获得，请检查]
+            TaskNotRunning: [任务不是running状态]
+            TaskNotExist: [任务不存在]
+
+        Returns:
+            [bool]: [成功则为true]
+        """
+
+            # 加锁
+            self.get_lock()
+            # 检查任务是否存在
+            target_task = self.tasks.get(task.key)
+            if target_task:
+                # 检查任务状态是否正确
+                if target_task.status == "running":
+                    # 检查nodeid是否正确
+                    if target_task.nodeId == task.nodeId:
+                        target_task.data = task.data
+                        target_task.status = "done"
+                        self.release_lock()
+                        return True
                     else:
                         self.release_lock()
-                        raise TaskNotRunning()
+                        raise NodeIdNotMatch()
                 else:
+                    self.release_lock()
+                    raise TaskNotRunning()
+            else:
                     self.release_lock()
                     raise TaskNotExist()
 
